netapp_ontap.resources.qtree API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.qtree`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

A qtree is a logically defined file system that can exist as a special subdirectory of the root directory within a FlexVol volume or a FlexGroup volume.

## Qtree QoS policy

Qtree QoS policy and settings enforce Service Level Objectives (SLOs) on a qtree. SLOs can be set by specifying "qos_policy.max_throughput_iops" and/or "qos_policy.max_throughput_mbps" or "qos_policy.min_throughput_iops" and/or "qos_policy.min_throughput_mbps". Specifying "min_throughput_iops" or "min_throughput_mbps" is only supported on volumes hosted on a node that is flash optimized. A pre-created QoS policy can also be used by specifying "qos_policy.name" or "qos_policy.uuid" properties. Setting or assigning a QoS policy to a qtree is not supported if its containing volume or SVM has a QoS policy attached, or a file or LUN in its containing volume already has a QoS policy attached.

## Performance monitoring

Performance of a qtree can be monitored by observing the `statistics.*` properties. These properties show the performance of the qtree in terms of IOPS and throughput. The `statistics.*` properties denote a real-time monotonically increasing value aggregated across all nodes.

### Extended performance monitoring

Extended performance monitoring enables the collection of latency statistics and the archival of statistics samples for a qtree. When extended performance monitoring is enabled for a qtree, its performance can be monitored by observing the `metric.*` and `statistics.*` properties. These properties show the performance of the qtree in terms of IOPS, latency and throughput. The `metric.*` properties denote an average whereas `statistics.*` properties denote a real-time monotonically increasing value aggregated across all nodes. Extended performance monitoring can be enabled for a qtree using the `ext_performance_monitoring.enabled` property. A maximum of 50,000 qtrees can have extended performance monitoring enabled on a cluster. If extended performance monitoring is enabled for an existing qtree, the prior `statistics.*` properties showing the IOPS and throughput performance of the qtree will be cleared. When extended performance monitoring is enabled for a qtree for the first time in an SVM, existing NFS clients might not be accounted for until their NFS shares associated with the SVM are remounted.

## Qtree APIs

The following APIs are used to create, retrieve, modify, and delete qtrees.

- POST /api/storage/qtrees
- GET /api/storage/qtrees
- GET /api/storage/qtrees/{volume-uuid}/{qtree-id}
- PATCH /api/storage/qtrees/{volume-uuid}/{qtree-id}
- DELETE /api/storage/qtrees/{volume-uuid}/{qtree-id}

## Examples

### Creating a qtree inside a volume for an SVM

This API is used to create a qtree inside a volume for an SVM.
The following example shows how to create a qtree in a FlexVol volume with a given security style, user, group, UNIX permissions, an export policy, and a QoS policy.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree()
        resource.svm = {"name": "svm1"}
        resource.volume = {"name": "fv"}
        resource.name = "qt1"
        resource.security_style = "unix"
        resource.user = {"name": "unix_user1"}
        resource.group = {"name": "unix_group1"}
        resource.unix_permissions = 744
        resource.export_policy = {"name": "default"}
        resource.qos_policy = {"max_throughput_iops": 1000}
        resource.post(hydrate=True)
        print(resource)

Try it out

    Qtree(
        {
            "unix_permissions": 744,
            "_links": {"self": {"href": "/api/storage/qtrees/?volume.name=fv&name=qt1"}},
            "export_policy": {"name": "default"},
            "svm": {"name": "svm1"},
            "name": "qt1",
            "security_style": "unix",
            "user": {"name": "unix_user1"},
            "volume": {"name": "fv"},
            "qos_policy": {
                "name": "vs0_auto_gen_policy_39a9522f_ff35_11e9_b0f9_005056a7ab52",
                "uuid": "39ac471f-ff35-11e9-b0f9-005056a7ab52",
            },
            "group": {"name": "unix_group1"},
        }
    )

### Retrieving qtrees

This API is used to retrieve qtrees.
The following example shows how to retrieve qtrees belonging to SVM svm1 and volume fv. The `svm.name` and `volume.name` query parameters are used to find the required qtrees.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(Qtree.get_collection(**{"svm.name": "svm1", "volume.name": "fv"})))

Try it out

    [
        Qtree(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/qtrees/cb20da45-4f6b-11e9-9a71-005056a7f717/0"
                    }
                },
                "svm": {
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/b68f961b-4cee-11e9-930a-005056a7f717"
                        }
                    },
                    "uuid": "b68f961b-4cee-11e9-930a-005056a7f717",
                },
                "name": "",
                "volume": {
                    "name": "fv",
                    "_links": {
                        "self": {
                            "href": "/api/storage/volumes/cb20da45-4f6b-11e9-9a71-005056a7f717"
                        }
                    },
                    "uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717",
                },
                "id": 0,
            }
        ),
        Qtree(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/qtrees/cb20da45-4f6b-11e9-9a71-005056a7f717/1"
                    }
                },
                "svm": {
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/b68f961b-4cee-11e9-930a-005056a7f717"
                        }
                    },
                    "uuid": "b68f961b-4cee-11e9-930a-005056a7f717",
                },
                "name": "qt1",
                "volume": {
                    "name": "fv",
                    "_links": {
                        "self": {
                            "href": "/api/storage/volumes/cb20da45-4f6b-11e9-9a71-005056a7f717"
                        }
                    },
                    "uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717",
                },
                "id": 1,
            }
        ),
        Qtree(
            {
                "_links": {
                    "self": {
                        "href": "/api/storage/qtrees/cb20da45-4f6b-11e9-9a71-005056a7f717/2"
                    }
                },
                "svm": {
                    "name": "svm1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/b68f961b-4cee-11e9-930a-005056a7f717"
                        }
                    },
                    "uuid": "b68f961b-4cee-11e9-930a-005056a7f717",
                },
                "name": "qt2",
                "volume": {
                    "name": "fv",
                    "_links": {
                        "self": {
                            "href": "/api/storage/volumes/cb20da45-4f6b-11e9-9a71-005056a7f717"
                        }
                    },
                    "uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717",
                },
                "id": 2,
            }
        ),
    ]

### Retrieving properties of a specific qtree using a qtree identifier

This API is used to retrieve properties of a specific qtree using qtree.id.
The following example shows how to use the qtree identifier to retrieve all properties of the qtree using the `fields` query parameter.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=2, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.get(fields="*")
        print(resource)

### Retrieving properties of a specific qtree using the qtree name

This API is used to retrieve properties of a specific qtree using "qtree.name". The following example shows how to retrieve all of the properties belonging to qtree "qt2". The `svm.name` and `volume.name` query parameters are used here along with the qtree name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                Qtree.get_collection(
                    name="qt2", fields="*", **{"svm.name": "svm1", "volume.name": "fv"}
                )
            )
        )

### Updating a qtree

This API is used to update a qtree.
The following example shows how to update properties in a qtree.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=2, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.security_style = "mixed"
        resource.user = {"name": "unix_user1"}
        resource.group = {"name": "unix_group1"}
        resource.unix_permissions = 777
        resource.export_policy = {"id": "9", "name": "exp1"}
        resource.qos_policy = {"uuid": "39ac471f-ff35-11e9-b0f9-005056a7ab53"}
        resource.patch()

### Renaming a qtree

This API is used to rename a qtree.
The following example below shows how to rename a qtree with a new name.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=1, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.name = "new_qt1"
        resource.patch()

### Deleting a qtree inside a volume of an SVM

This API is used to delete a qtree inside a volume of an SVM. The following example shows how to delete a qtree.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=2, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.delete()

### Enabling extended performance monitoring on a qtree using PATCH

This API is used to enable extended performance monitoring on a qtree. The following example shows how to enable extended performance monitoring on a qtree.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=1, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.ext_performance_monitoring = {"enabled": "true"}
        resource.patch()

### Disabling extended performance monitoring on a qtree using PATCH

This API is used to disable extended performance monitoring on a qtree. The following example shows how to disable extended performance monitoring on a qtree.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=1, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.ext_performance_monitoring = {"enabled": "false"}
        resource.patch()

### Retrieving performance properties for a qtree which has extended performance monitoring enabled

The following example shows how to use a GET request to retrieve performance properties for a qtree which has extended performance monitoring enabled.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import Qtree

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = Qtree(id=3, **{"volume.uuid": "cb20da45-4f6b-11e9-9a71-005056a7f717"})
        resource.get(fields="ext_performance_monitoring,statistics,metric")
        print(resource)

## Classes

`class Qtree (*args, **kwargs)`

  A qtree is a directory at the top level of a volume to which a custom export policy (for fine-grained access control) and a quota rule can be applied, if required.

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all Qtree resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('Qtree')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a qtree.

    ### Related ONTAP commands

    - `qtree delete`

    ### Learn more

    - `DOC /storage/qtrees`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent Qtree resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves qtrees configured for all FlexVol volumes or FlexGroup volumes.
    Use the `fields` query parameter to retrieve all properties of the qtree. If the `fields` query parameter is not used, then GET returns the qtree `name` and qtree `id` only.

    ### Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `ext_performance_monitoring.enabled` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `qtree show`

    ### Learn more

    - `DOC /storage/qtrees`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves qtrees configured for all FlexVol volumes or FlexGroup volumes.
    Use the `fields` query parameter to retrieve all properties of the qtree. If the `fields` query parameter is not used, then GET returns the qtree `name` and qtree `id` only.

    ### Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `ext_performance_monitoring.enabled` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `qtree show`

    ### Learn more

    - `DOC /storage/qtrees`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('Qtree')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates properties for a specific qtree.

    ### Related ONTAP commands

    - `qtree modify`
    - `qtree rename`

    ### Learn more

    - `DOC /storage/qtrees`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('Qtree')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[Qtree], NetAppResponse]`

    Creates a qtree in a FlexVol volume or a FlexGroup volume.
    After a qtree is created, the new qtree is assigned an identifier. This identifier is obtained using a qtree GET request. This identifier is used in the API path for the qtree PATCH and DELETE operations.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the qtree.
    - `volume.uuid` or `volume.name` - Existing volume in which to create the qtree.
    - `name` - Name for the qtree.

    ### Recommended optional properties

    If not specified in POST, the values are inherited from the volume. * `security_style` - Security style for the qtree. * `unix_permissions` - UNIX permissions for the qtree. * `export_policy.name or export_policy.id` - Export policy of the SVM for the qtree.

    ### Related ONTAP commands

    - `qtree create`

    ### Learn more

    - `DOC /storage/qtrees`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes a qtree.

    ### Related ONTAP commands

    - `qtree delete`

    ### Learn more

    - `DOC /storage/qtrees`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves properties for a specific qtree identified by the `volume.uuid` and the `id` in the API path.

    ### Expensive properties

    There is an added computational cost to retrieving values for these properties. They are not included by default in GET results and must be explicitly requested using the `fields` query parameter. See `Requesting specific fields` to learn more. * `ext_performance_monitoring.enabled` * `statistics.*` * `metric.*`

    ### Related ONTAP commands

    - `qtree show`

    ### Learn more

    - `DOC /storage/qtrees`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates properties for a specific qtree.

    ### Related ONTAP commands

    - `qtree modify`
    - `qtree rename`

    ### Learn more

    - `DOC /storage/qtrees`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates a qtree in a FlexVol volume or a FlexGroup volume.
    After a qtree is created, the new qtree is assigned an identifier. This identifier is obtained using a qtree GET request. This identifier is used in the API path for the qtree PATCH and DELETE operations.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the qtree.
    - `volume.uuid` or `volume.name` - Existing volume in which to create the qtree.
    - `name` - Name for the qtree.

    ### Recommended optional properties

    If not specified in POST, the values are inherited from the volume. * `security_style` - Security style for the qtree. * `unix_permissions` - UNIX permissions for the qtree. * `export_policy.name or export_policy.id` - Export policy of the SVM for the qtree.

    ### Related ONTAP commands

    - `qtree create`

    ### Learn more

    - `DOC /storage/qtrees`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class QtreeSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Qtree object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `export_policy: ExportPolicy GET POST PATCH`

    The export_policy field of the qtree.

  `ext_performance_monitoring: QtreeExtPerformanceMonitoring GET POST PATCH`

    The ext_performance_monitoring field of the qtree.

  `group: QtreeGroup GET POST PATCH`

    The user set as owner of the qtree.

  `id: Size GET`

    The identifier for the qtree, unique within the qtree's volume.

    Example: 1

  `links: SelfLink GET`

    The links field of the qtree.

  `metric: PerformanceQtreeMetricData GET`

    Performance numbers, such as IOPS latency and throughput.

  `name: str GET POST PATCH`

    The name of the qtree. Required in POST; optional in PATCH.

  `nas: QtreeNas GET POST PATCH`

    The nas field of the qtree.

  `path: str GET`

    Client visible path to the qtree. This field is not available if the volume does not have a junction-path configured. Not valid in POST or PATCH. This field is to be deprecated and replaced with nas.path.

    Example: /volume3/qtree1

  `qos_policy: QosPolicy GET POST PATCH`

    The qos_policy field of the qtree.

  `security_style: str GET POST PATCH`

    The security_style field of the qtree.

  `statistics: QtreeStatisticsRaw GET`

    The statistics field of the qtree.

  `svm: Svm GET POST`

    The svm field of the qtree.

  `tags: List[str] GET POST PATCH`

    Tags are an optional way to track the uses of a resource. Tag values must be formatted as key:value strings.

    Example: ["team:csi","environment:test"]

  `unix_permissions: Size GET POST PATCH`

    The UNIX permissions for the qtree. Valid in POST or PATCH.

    Example: 493

  `user: QtreeUser GET POST PATCH`

    The user set as owner of the qtree.

  `volume: Volume GET POST`

    The volume field of the qtree.